@@ -23,8 +23,8 @@
 #define GLOBALS_H
 
 #include <QList>
-#include <QString>
 #include <QMetaEnum>
+#include <QString>
 
 #include "logMode.h"
 #include "logModeFactory.h"
@@ -46,7 +46,7 @@ class Globals : QObject
 public:
     static Globals &instance();
 
-    ~Globals();
+    ~Globals() override;
 
     enum LogLevelIds {
         EMERGENCY_LOG_LEVEL_ID = 0,
@@ -67,17 +67,17 @@ public:
 
     QString formatDate(DateFormat format, const QDateTime &dateTime) const;
 
-    QList<LogLevel *> logLevels();
+    QHash<LogLevelIds, LogLevel *> logLevels() const;
 
-    LogLevel *noLogLevel();
-    LogLevel *debugLogLevel();
-    LogLevel *informationLogLevel();
-    LogLevel *noticeLogLevel();
-    LogLevel *warningLogLevel();
-    LogLevel *errorLogLevel();
-    LogLevel *criticalLogLevel();
-    LogLevel *alertLogLevel();
-    LogLevel *emergencyLogLevel();
+    LogLevel *noLogLevel() const;
+    LogLevel *debugLogLevel() const;
+    LogLevel *informationLogLevel() const;
+    LogLevel *noticeLogLevel() const;
+    LogLevel *warningLogLevel() const;
+    LogLevel *errorLogLevel() const;
+    LogLevel *criticalLogLevel() const;
+    LogLevel *alertLogLevel() const;
+    LogLevel *emergencyLogLevel() const;
 
     LogLevel *logLevelByPriority(int id);
 
@@ -88,9 +88,9 @@ public:
      */
     void registerLogModeFactory(LogModeFactory *logModeFactory);
 
-    QList<LogMode *> logModes();
+    QList<LogMode *> logModes() const;
 
-    QList<LogModeAction *> logModeActions();
+    QList<LogModeAction *> logModeActions() const;
 
     LogMode *findLogMode(const QString &logModeName);
 
