@@ -24,8 +24,8 @@
 #include <QAction>
 #include <QFileInfo>
 
-#include "multipleActions.h"
 #include "logModeItemBuilder.h"
+#include "multipleActions.h"
 
 LogMode::LogMode(const QString &id, const QString &name, const QString &iconName)
     : d(new LogModePrivate())
@@ -87,7 +87,7 @@ LogModeConfiguration *LogMode::innerConfiguration() const
 
 QAction *LogMode::createDefaultAction()
 {
-    QAction *action = new QAction(d->icon, d->name, this);
+    auto action = new QAction(d->icon, d->name, this);
     ActionData data;
     data.id = d->id;
     action->setData(QVariant::fromValue(data));
@@ -100,7 +100,8 @@ void LogMode::checkLogFilesPresence(const QStringList &paths)
     d->logFilesExist = false;
     for (const QString &path : paths) {
         QFileInfo fileInfo(path);
-        if (fileInfo.exists())
+        if (fileInfo.exists()) {
             d->logFilesExist = true;
+        }
     }
 }
