@@ -29,8 +29,8 @@
 #include "logging.h"
 
 #include "logLine.h"
-#include "logViewWidgetItem.h"
 #include "logMode.h"
+#include "logViewWidgetItem.h"
 
 #include "logModeItemBuilder.h"
 
@@ -39,26 +39,15 @@ class LogLine;
 class AcpidItemBuilder : public LogModeItemBuilder
 {
 public:
-    AcpidItemBuilder() {}
-
-    ~AcpidItemBuilder() override {}
-
-    QString createFormattedText(LogLine *line) const override
+    AcpidItemBuilder()
     {
-        QString result;
-
-        QListIterator<QString> it(line->logItems());
-
-        result.append(QLatin1String("<table>"));
-
-        result.append(labelMessageFormat(i18n("Date:"), formatDate(line->time())));
-        result.append(labelMessageFormat(i18n("Level:"), line->logLevel()->name()));
-        result.append(labelMessageFormat(i18n("Type:"), it.next()));
-
-        result.append(QLatin1String("</table>"));
-
-        return result;
     }
+
+    ~AcpidItemBuilder() override
+    {
+    }
+
+    QString createFormattedText(LogLine *line) const override;
 };
 
 #endif // _ACPID_ITEM_BUILDER_H
