@@ -26,62 +26,35 @@
 
 #include "logModeConfiguration.h"
 
-#include "logging.h"
 #include "defaults.h"
+#include "logging.h"
 
 #include "authenticationLogMode.h"
 
 #include "ksystemlogConfig.h"
 
-class AuthenticationConfigurationPrivate
-{
-public:
-    QString authenticationPath;
-
-    QStringList warningKeywords;
-    QStringList errorKeywords;
-};
-
 class AuthenticationConfiguration : public LogModeConfiguration
 {
     Q_OBJECT
 
 public:
-    AuthenticationConfiguration()
-        : d(new AuthenticationConfigurationPrivate())
-    {
-        configuration->setCurrentGroup(QStringLiteral("AuthenticationLogMode"));
+    AuthenticationConfiguration();
 
-        QString defaultAuthenticationPath(QStringLiteral("/var/log/auth.log"));
-        configuration->addItemString(QStringLiteral("LogFilePath"), d->authenticationPath,
-                                     defaultAuthenticationPath, QStringLiteral("LogFilePath"));
+    ~AuthenticationConfiguration() override;
 
-        QStringList defaultWarningKeywords;
-        defaultWarningKeywords.append(QStringLiteral("failed"));
-        configuration->addItemStringList(QStringLiteral("WarningKeywords"), d->warningKeywords,
-                                         defaultWarningKeywords, QStringLiteral("WarningKeywords"));
+    QString authenticationPath() const;
 
-        QStringList defaultErrorKeywords;
-        defaultErrorKeywords.append(QStringLiteral("error"));
-        configuration->addItemStringList(QStringLiteral("ErrorKeywords"), d->errorKeywords,
-                                         defaultErrorKeywords, QStringLiteral("ErrorKeywords"));
-    }
+    void setAuthenticationPath(const QString &authenticationPath);
 
-    virtual ~AuthenticationConfiguration() { delete d; }
+    QStringList warningKeywords() const;
 
-    QString authenticationPath() const { return d->authenticationPath; }
-
-    void setAuthenticationPath(const QString &authenticationPath)
-    {
-        d->authenticationPath = authenticationPath;
-    }
-
-    QStringList warningKeywords() const { return d->warningKeywords; }
-
-    QStringList errorKeywords() const { return d->errorKeywords; }
+    QStringList errorKeywords() const;
 
 private:
-    AuthenticationConfigurationPrivate *const d;
+    QString mAuthenticationPath;
+
+    QStringList mWarningKeywords;
+    QStringList mErrorKeywords;
 };
 
 #endif // _AUTHENTICATION_CONFIGURATION_H
