@@ -22,12 +22,12 @@
 #ifndef SYSTEM_CONFIGURATION_H
 #define SYSTEM_CONFIGURATION_H
 
-#include <QStringList>
 #include <QList>
+#include <QStringList>
 
+#include "defaults.h"
 #include "genericConfiguration.h"
 #include "globals.h"
-#include "defaults.h"
 
 #include "systemLogMode.h"
 
@@ -36,18 +36,11 @@ class SystemConfiguration : public GenericLogModeConfiguration
     Q_OBJECT
 
 public:
-    SystemConfiguration()
-        : GenericLogModeConfiguration(QStringLiteral(SYSTEM_LOG_MODE_ID),
-                                      QStringList() << QStringLiteral("/var/log/syslog"),
-                                      QList<int>() << Globals::INFORMATION_LOG_LEVEL_ID)
-    {
-        /*
-        <default>/var/log/messages,/var/log/syslog,/var/log/debug</default>
-        <default>2,2,1</default>
-        */
-    }
+    SystemConfiguration();
 
-    virtual ~SystemConfiguration() {}
+    ~SystemConfiguration() override
+    {
+    }
 };
 
 #endif // _SYSTEM_CONFIGURATION_H
